"use strict";

exports.__esModule = true;

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _propTypes = require("prop-types");

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * React Component to highlight any part of the containing block in reactangle size.
 */

var ReactBlockHighlight = function ReactBlockHighlight(_ref) {
  var id = _ref.id,
      x = _ref.x,
      y = _ref.y,
      height = _ref.height,
      width = _ref.width,
      opacity = _ref.opacity,
      color = _ref.color,
      children = _ref.children;

  var canvasRef = (0, _react.useRef)(null);
  var ctx = (0, _react.useRef)();
  var canvas = (0, _react.useRef)({});

  (0, _react.useEffect)(function () {
    ctx.current = canvasRef.current.getContext("2d");
  }, []);

  (0, _react.useEffect)(function () {
    canvas.current = document.getElementById(id) || {};
    ctx.current.clearRect(0, 0, canvas.current.width, canvas.current.height);
    ctx.current.globalAlpha = opacity;
    ctx.current.fillStyle = color;
    ctx.current.fillRect(x, y, width, height);
    ctx.current.lineWidth = .2;
    ctx.current.strokeStyle = "#FF0000";
    ctx.current.strokeRect(x, y, width, height);
  }, [x, y, height, width, id, color, opacity]);

  return _react2.default.createElement(
    "section",
    { style: { position: "relative", left: "0", top: "0" } },
    children,
    _react2.default.createElement("canvas", { style: { width: "100%", height: "100%", position: "absolute", top: "0", "left": "0" }, ref: canvasRef, id: id })
  );
};

ReactBlockHighlight.propTypes = process.env.NODE_ENV !== "production" ? {
  /** Unique id for the canvas element */
  id: _propTypes2.default.string,
  /** x-coordinate of starting point */
  x: _propTypes2.default.number,
  /** y-coordinate of starting point */
  y: _propTypes2.default.number,
  /** Height of the area to be highlighted */
  height: _propTypes2.default.number,
  /** Width of the area to be highlighted */
  width: _propTypes2.default.number,
  /** Opacity of the area to be highlighted */
  opacity: _propTypes2.default.number,
  /** Color of the area to be highlighted */
  color: _propTypes2.default.string
} : {};

ReactBlockHighlight.defaultProps = {
  id: "block-highlight-canvas",
  opacity: .5,
  color: "#ffff00",
  x: 0,
  y: 0,
  width: 250,
  height: 20
};

exports.default = ReactBlockHighlight;
module.exports = exports["default"];